@@ -144,7 +144,7 @@ g_mime_multipart_finalize (GObject *object)
 		GMimeObject *part;
 		
 		part = node->data;
-		g_mime_object_unref (part);
+		g_object_unref (part);
 		node = node->next;
 	}
 	g_list_free (multipart->subparts);
@@ -238,8 +238,7 @@ multipart_write_to_stream (GMimeObject *object, GMimeStream *stream)
 		g_mime_multipart_set_boundary (multipart, NULL);
 	
 	/* write the content headers */
-	nwritten = g_mime_header_write_to_stream (object->headers, stream);
-	if (nwritten == -1)
+	if ((nwritten = g_mime_header_write_to_stream (object->headers, stream)) == -1)
 		return -1;
 	
 	total += nwritten;
@@ -252,8 +251,7 @@ multipart_write_to_stream (GMimeObject *object, GMimeStream *stream)
 		
 		total++;
 		
-		nwritten = g_mime_stream_write_string (stream, multipart->preface);
-		if (nwritten == -1)
+		if ((nwritten = g_mime_stream_write_string (stream, multipart->preface)) == -1)
 			return -1;
 		
 		total += nwritten;
@@ -264,15 +262,13 @@ multipart_write_to_stream (GMimeObject *object, GMimeStream *stream)
 		part = node->data;
 		
 		/* write the boundary */
-		nwritten = g_mime_stream_printf (stream, "\n--%s\n", multipart->boundary);
-		if (nwritten == -1)
+		if ((nwritten = g_mime_stream_printf (stream, "\n--%s\n", multipart->boundary)) == -1)
 			return -1;
 		
 		total += nwritten;
 		
 		/* write this part out */
-		nwritten = g_mime_object_write_to_stream (part, stream);
-		if (nwritten == -1)
+		if ((nwritten = g_mime_object_write_to_stream (part, stream)) == -1)
 			return -1;
 		
 		total += nwritten;
@@ -280,16 +276,14 @@ multipart_write_to_stream (GMimeObject *object, GMimeStream *stream)
 		node = node->next;
 	}
 	
-	nwritten = g_mime_stream_printf (stream, "\n--%s--\n", multipart->boundary);
-	if (nwritten == -1)
+	if ((nwritten = g_mime_stream_printf (stream, "\n--%s--\n", multipart->boundary)) == -1)
 		return -1;
 	
 	total += nwritten;
 	
 	/* write the postface */
 	if (multipart->postface) {
-		nwritten = g_mime_stream_write_string (stream, multipart->postface);
-		if (nwritten == -1)
+		if ((nwritten = g_mime_stream_write_string (stream, multipart->postface)) == -1)
 			return -1;
 		
 		total += nwritten;
@@ -419,7 +413,7 @@ g_mime_multipart_get_postface (GMimeMultipart *multipart)
 static void
 multipart_add_part (GMimeMultipart *multipart, GMimeObject *part)
 {
-	g_mime_object_ref (part);
+	g_object_ref (part);
 	multipart->subparts = g_list_append (multipart->subparts, part);
 }
 
@@ -444,7 +438,7 @@ g_mime_multipart_add_part (GMimeMultipart *multipart, GMimeObject *part)
 static void
 multipart_add_part_at (GMimeMultipart *multipart, GMimeObject *part, int index)
 {
-	g_mime_object_ref (part);
+	g_object_ref (part);
 	multipart->subparts = g_list_insert (multipart->subparts, part, index);
 }
 
@@ -500,7 +494,7 @@ multipart_remove_part (GMimeMultipart *multipart, GMimeObject *part)
 	
 	g_list_free_1 (node);
 	
-	g_mime_object_unref (part);
+	g_object_unref (part);
 }
 
 
@@ -582,7 +576,7 @@ multipart_get_part (GMimeMultipart *multipart, int index)
 	
 	part = node->data;
 	
-	g_mime_object_ref (part);
+	g_object_ref (part);
 	
 	return part;
 }
@@ -639,10 +633,8 @@ read_random_pool (char *buffer, size_t bytes)
 {
 	int fd;
 	
-	fd = open ("/dev/urandom", O_RDONLY);
-	if (fd == -1) {
-		fd = open ("/dev/random", O_RDONLY);
-		if (fd == -1)
+	if ((fd = open ("/dev/urandom", O_RDONLY)) == -1) {
+		if ((fd = open ("/dev/random", O_RDONLY)) == -1)
 			return;
 	}
 	
@@ -730,7 +722,7 @@ g_mime_multipart_get_boundary (GMimeMultipart *multipart)
  * @callback: function to call for @multipart and all of its subparts
  * @user_data: extra data to pass to the callback
  * 
- * Calls @callback on @multipart and each of its subparts.
+ * Calls @callback on each of @multipart's subparts.
  **/
 void
 g_mime_multipart_foreach (GMimeMultipart *multipart, GMimePartFunc callback, gpointer user_data)
