@@ -257,67 +257,6 @@ internet_address_add_member (InternetAddress *ia, InternetAddress *member)
 }
 
 
-/**
- * internet_address_get_type:
- * @ia: internet address
- *
- * Returns the type of the internet address.
- **/
-InternetAddressType
-internet_address_get_type (InternetAddress *ia)
-{
-	g_return_val_if_fail (ia != NULL, INTERNET_ADDRESS_NONE);
-
-	return ia->type;
-}
-
-/**
- * internet_address_get_name:
- * @ia: internet address
- *
- * Returns the name of the internet address.
- **/
-const char *
-internet_address_get_name (InternetAddress *ia)
-{
-	g_return_val_if_fail (ia != NULL, NULL);
-
-	return ia->name;
-}
-
-
-/**
- * internet_address_get_addr:
- * @ia: internet address
- *
- * Returns the address of the internet address.
- **/
-const char *
-internet_address_get_addr (InternetAddress *ia)
-{
-	g_return_val_if_fail (ia != NULL, NULL);
-	g_return_val_if_fail (ia->type != INTERNET_ADDRESS_GROUP, NULL);
-
-	return ia->value.addr;
-}
-
-
-/**
- * internet_address_get_members:
- * @ia: internet address
- *
- * Returns the list of internet addresses
- **/
-const InternetAddressList *
-internet_address_get_members (InternetAddress *ia)
-{
-	g_return_val_if_fail (ia != NULL, NULL);
-	g_return_val_if_fail (ia->type != INTERNET_ADDRESS_NAME, NULL);
-
-	return ia->value.members;
-}
-
-
 /**
  * internet_address_list_prepend:
  * @list: a list of internet addresses
@@ -422,36 +361,6 @@ internet_address_list_concat (InternetAddressList *a, InternetAddressList *b)
 }
 
 
-/**
- * internet_address_list_next:
- * @list: list of internet addresses
- *
- * Returns the following node in @list.
- **/
-InternetAddressList *
-internet_address_list_next (const InternetAddressList *list)
-{
-	if (!list)
-		return NULL;
-
-	return list->next;
-}
-
-/**
- * internet_address_list_get_address:
- * @list: list of internet addresses
- *
- * Returns the #InternetAddress currently pointed to in @list.
- **/
-InternetAddress *
-internet_address_list_get_address (const InternetAddressList *list)
-{
-	if (!list)
-		return NULL;
-
-	return list->address;
-}
-
 /**
  * internet_address_list_length:
  * @list: list of internet addresses
@@ -546,10 +455,12 @@ internet_address_list_to_string_internal (const InternetAddressList *list, gbool
 char *
 internet_address_to_string (const InternetAddress *ia, gboolean encode)
 {
-	char *name, *str = NULL;
+	char *str = NULL;
 	
 	if (ia->type == INTERNET_ADDRESS_NAME) {
 		if (ia->name && *ia->name) {
+			char *name;
+			
 			name = encoded_name (ia->name, encode);
 			str = g_strdup_printf ("%s <%s>", name, ia->value.addr);
 			g_free (name);
@@ -560,10 +471,8 @@ internet_address_to_string (const InternetAddress *ia, gboolean encode)
 		InternetAddressList *members;
 		GString *string;
 		
-		name = encoded_name (ia->name, encode);
-		string = g_string_new (name);
+		string = g_string_new (ia->name);
 		g_string_append (string, ": ");
-		g_free (name);
 		
 		members = ia->value.members;
 		internet_address_list_to_string_internal (members, encode, string);
